'use strict';

exports.__esModule = true;

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _stcHelper = require('stc-helper');

var _safe = require('colors/safe');

var _safe2 = _interopRequireDefault(_safe);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_safe2.default.enabled = true;

/**
 * stc logger class
 */

var StcLog = function () {
  /**
   * constructor
   */
  function StcLog() {
    (0, _classCallCheck3.default)(this, StcLog);

    this.hasError = false;
    this.hasLog = false;
  }
  /**
   * add error log
   */


  StcLog.prototype.error = function error(message) {
    this.hasError = true;
    this.display(message, 'error');
  };
  /**
   * add warning log
   */


  StcLog.prototype.warning = function warning(message) {
    this.display(message, 'warning');
  };
  /**
   * add notice log
   */


  StcLog.prototype.notice = function notice(message) {
    this.display(message, 'notice');
  };
  /**
   * display item log
   */


  StcLog.prototype.display = function display(message, type) {
    this.hasLog = true;
    var isFn = false;
    if (typeof message === 'function') {
      isFn = true;
      message = message(_safe2.default);
    }
    if (message && (0, _stcHelper.isObject)(message) && 'message' in message) {
      var str = '';
      if (message.className) {
        str = message.className + ': ' + message.message + ';';
      } else {
        str = message.message;
      }
      if (message.file) {
        str += ' in file `' + message.file + '`';
      }
      if (message.line !== undefined) {
        str += ' on line: ' + (message.line + 1) + ', column: ' + (message.column + 1);
      }
      message = str;
    }

    if (typeof window !== 'undefined') {
      switch (type) {
        case 'error':
          message = console.error(message);
          break;
        case 'warning':
          message = console.warn(message);
          break;
        default:
          if (!isFn) {
            message = console.log(message);
          }
      }
      return;
    }

    switch (type) {
      case 'error':
        message = _safe2.default.red(message);
        break;
      case 'warning':
        message = _safe2.default.yellow(message);
        break;
      default:
        if (!isFn) {
          message = _safe2.default.green(message);
        }
    }
    console.log(message);
  };

  return StcLog;
}();

exports.default = StcLog;
//# sourceMappingURL=index.js.map